# `royalpack`

## Required configuration options

```toml
Imgur.token = 
Telegram.main_group_id = 
Discord.main_channel_id = 
Dota.updater = 
Peertube.instance_url = 
Peertube.feed_update_timeout = 
Funkwhale.instance_url = 
Cv.displayed_role_id = 
Lol.token = 
Lol.region = 
Lol.updater = 
Play.max_song_duration = 
Steam.web_api_key = 
Brawlhalla.api_key = 
Brawlhalla.updater = 
Matchmaking.mm_chat_id = 
```